..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

==============
 Invenio-Mail
==============

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-mail.svg
        :target: https://github.com/inveniosoftware/invenio-mail/blob/master/LICENSE

.. image:: https://img.shields.io/travis/inveniosoftware/invenio-mail.svg
        :target: https://travis-ci.org/inveniosoftware/invenio-mail

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-mail.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-mail

.. image:: https://img.shields.io/pypi/v/invenio-mail.svg
        :target: https://pypi.org/pypi/invenio-mail

Invenio-Mail is an integration layer between Invenio and Flask-Mail.

Further documentation is available on
https://invenio-mail.readthedocs.io/
